<?php

    //   _           _           
    //  (_)_ __   __| | _____  __
    //  | | '_ \ / _` |/ _ \ \/ /
    //  | | | | | (_| |  __/>  < 
    //  |_|_| |_|\__,_|\___/_/\_\
    //  
    // ==========================================================================
    //  A PHP utility to do a Macintosh style 'Light Box' display of a bunch of
    //  thumbnail photos, where clicking on a photo causes some Javascript magic
    //  to display a larger version of the photo nicly centered on the page with
    //  a small (X) in the upper right corner to close it.  This is all done via
    //  configuration by a partner PHP file called config.php in this directory.
    //                                                H Marc Lewis -- March-2011
    // ==========================================================================
    ini_set('display_errors',1);
    $version = "1.1";

    // ---------------------------------------------------------
    // If this utility isn't configured yet, go do that first...
    // ---------------------------------------------------------
    if (!file_exists("tools/CONFIGURED")) {
        header("Location: config.php");
        exit(0);
        }

    $body     = "";
    $Rotation = Array();
    $Args     = Array();
    $x = file_get_contents("tools/CONFIGURED");
    if (empty($x)) {
        print "<h3>File tools/CONFIGURED is empty &mdash; please delete it and reload</h3>";
        exit(0);
        }
    else {
        $Args = unserialize($x);
//foreach ($Args as $key => $value)
//print "$key => '$value'<br>\n";
        $background = $Args['Background'];
        $bodytext   = $Args['BodyText'];
        $border     = $Args['Border'];
        $copyright  = $Args['Copyright'];
        $fonts      = $Args['Fonts'];
        $fontsize   = $Args['FontSize'];
        $height     = $Args['Height'];
        $namecolor  = $Args['NameColor'];
        $pagecolor  = $Args['PageColor'];
        $quality    = $Args['Quality'];
        $repeatX    = $Args['RepeatX'];
        $repeatY    = $Args['RepeatY'];
        $spacing    = $Args['Spacing'];
        $showname   = $Args['ShowName'];
        $title      = $Args['Title'];
        $titlecolor = $Args['TitleColor'];
        $titlefont  = $Args['TitleFont'];
        }

    // ----------------------------------------------------------------
    // Give user a button to quickly re-configure if still in test mode
    // ----------------------------------------------------------------
    if (!file_exists("tools/PUBLISHED")) {
        $cButton = "<p class='center'><input type='button' class='button' "
                        ."value='Re-Configure' onclick='window.location.href=\"config.php\"'>";
        }
    else
        $cButton = "";
    sendHeader($title,$bodytext,$fonts,$fontsize,$titlefont,$cButton,$background,
               $pagecolor,$repeatX,$repeatY,$titlecolor,$border,$namecolor);
        
    if ($image = opendir("thumb")) {
        while ($name = readdir($image)) {
//print "$name<br>";
            if ('.jpg' == strtolower(substr($name,-4))
                    or '.jpeg' == strtolower(substr($name,-5))
                    or '.png' == strtolower(substr($name,-4))
                    or '.gif' == strtolower(substr($name,-4))) {
                $Rotation[] = $name;
                }
            }
        }
    if (count($Rotation)) {
        asort($Rotation);
        $first = $Rotation[0];
        ini_set('display_errors',0);    // lots of .TXT files won't be there
        foreach ($Rotation as $name) {
//print "Rotation = $name<br>";
            $body .= showThumb($name,$spacing,$showname);
            }
        }
    print $body;
    sendFooter($copyright,$version);


// ==================================================================
//  Display a single thumbnail photo in a floating DIV so the images
//  will fill whatever screen size the user has at the moment.
// ==================================================================
function showThumb($name,$spacing,$showname)
{
    $html = preg_replace("/\.jpg|\.jpeg|\.png|\.gif$/i",".txt",$name);
    $text = file_get_contents($html);
    if (empty($text)) 
        $title = ""; // to prevent validation errors
    else
        $title = "title='$text'";
    if ($showname)
        $filename = "<br><span class='filename'>$name</span>";
    else
        $filename = "";
    return <<<RETURN
<div class='center' style="float: left; margin: $spacing;">
<a href="$name" class='LB' $title><img src="thumb/$name" alt="$name"></a>$filename
</div>
RETURN;

}


// =========================
//  Write the HTML 5 header
// =========================
function sendHeader($title,$text,$font,$size,$titlefont,$button,$background,
                    $pagecolor,$repeatx,$repeaty,$titlecolor,$border,$namecolor)
{
    if (!empty($pagecolor))
        $pagecolor = "background-color: $pagecolor;";
    if (!empty($background)) {
        $background = "background: url($background) ";
        if (!empty($repeatx)) $background .= " repeat-x ";
        if (!empty($repeaty)) $background .= " repeat-y ";
        $background .= ";";
        }
    if (!empty($titlecolor))
        $titlecolor = "color: $titlecolor;";
    if ($border+0)
        $imgborder = "img { border: ${border}px solid black; }";
    else
        $imgborder = "";
    if (!empty($namecolor))
        $namecolor = "color: $namecolor;";
    print <<<HEADER
<!DOCTYPE html>
<html>
<head>
<meta charset="utf-8">
<meta NAME="description" CONTENT="A PHP utility to generate a pleasing
    'LightBox' type display of thumbnails for photos in the current directory">
<meta name="copyright" content="2011 by H Marc Lewis. All rights reserved.">
<title>$title</title>

<script type="text/javascript" 
    src="http://ajax.googleapis.com/ajax/libs/jquery/1.5/jquery.min.js">
</script>
<script type="text/javascript" src="tools/jquery.mousewheel-3.0.4.pack.js">
</script>
<script type="text/javascript" src="tools/jquery.fancybox-1.3.4.pack.js">
</script>
<script type="text/javascript">
    $(document).ready(function() {
        $("a.LB").fancybox({ 'titlePosition' : 'inside' });
    });
</script>
<link rel="stylesheet" type="text/css" href="tools/jquery.fancybox-1.3.4.css"
        media="screen">
<style type='text/css'>
body {  font-family: $font;
        font-size: $size;
        margin: 1em 2em;
        color: black;
        $pagecolor
        $background
        }
h1 {    font-family: $titlefont; 
        $titlecolor
        }
a.LB,
a.LB:hover { text-decoration: none;
             border: none;
             }
.left {     text-align: left; }
.center {   text-align: center; }
.right {    text-align: right; }
.top {      vertical-align: top; }
.middle {   vertical-align: middle; }
.bottom {   vertical-align: bottom; }
.button {   font-size: 100%;
            color: #900;
            }
.filename { font-size: 80%;
            $namecolor
            }
$imgborder
</style>

</head>
<body>

<h1 class='center'> $title </h1>
$button
<p style='clear: both;'>
$text
HEADER;
}


// =========================
//  Write the HTML 5 footer
// =========================
function sendFooter($copyright,$version)
{
    if (!empty($copyright))
        $copyright .= "<br>";
    print <<<FOOTER
<p style='clear: both; text-align: center; font-size: 80%; margin: 0 5em;'>
$copyright
<a href='/lightbox/'>LightBox</a> v$version &copy; 2011 is a utility by 
<a href='http://hmarc.com/'>H. Marc Lewis</a>, 
incorporating ideas from <a href="http://paukstis.com/">Carl Paukstis</a>,<br>
plus <a href='http://jquery.com/'>JQuery</a>
and some Javascript code from <a href='http://fancybox.net'>Janis Skarnelis</a>.

</body>
</html>
FOOTER;
}
?>
